@@ -18,17 +18,21 @@ ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEAL
 '''
 from fantastico import mvc
 from fantastico.contrib.roa_discovery import roa_helper
+from fantastico.exceptions import FantasticoDbError
 from fantastico.mvc.base_controller import BaseController
 from fantastico.mvc.controller_decorators import ControllerProvider, Controller
 from fantastico.mvc.model_facade import ModelFacade
+from fantastico.mvc.models.model_filter import ModelFilter
+from fantastico.mvc.models.model_filter_compound import ModelFilterAnd
+from fantastico.oauth2.exceptions import OAuth2UnauthorizedError, OAuth2Error
 from fantastico.roa.query_parser import QueryParser
 from fantastico.roa.resource_json_serializer import ResourceJsonSerializer
 from fantastico.roa.resources_registry import ResourcesRegistry
 from fantastico.roa.roa_exceptions import FantasticoRoaError
 from fantastico.settings import SettingsFacade
+from fantastico.utils.dictionary_object import DictionaryObject
 from webob.response import Response
 import json
-from fantastico.exceptions import FantasticoDbError
 
 @ControllerProvider()
 class RoaController(BaseController):
@@ -37,8 +41,8 @@ class RoaController(BaseController):
 
     SETTINGS_FACADE = SettingsFacade()
     ROA_API = roa_helper.normalize_absolute_roa_uri(SETTINGS_FACADE.get("roa_api"))
-    BASE_URL = r"%s/(?P<version>\d{1,}\.\d{1,})(?P<resource_url>/.*?)" % ROA_API
-    BASE_LATEST_URL = "%s/latest(?P<resource_url>/.*?)" % ROA_API
+    BASE_URL = r"%s/(?P<version>\d{1,}\.\d{1,})(?P<resource_url>/[^/]*?)" % ROA_API
+    BASE_LATEST_URL = "%s/latest(?P<resource_url>/[^/]*?)" % ROA_API
 
     OFFSET_DEFAULT = 0
     LIMIT_DEFAULT = 100
@@ -200,9 +204,20 @@ class RoaController(BaseController):
         if not resource:
             return self._handle_resource_notfound(version, resource_url)
 
+        self._inject_security_context(request, resource.model)
+        access_token = self.validate_security_context(request, "read")
+
         json_serializer = self._json_serializer_cls(resource)
 
         filter_expr = self._parse_filter(params.filter_expr, resource.model)
+
+        if resource.user_dependent:
+            if filter_expr:
+                filter_expr = ModelFilterAnd(filter_expr, ModelFilter(resource.model.user_id, access_token.user_id,
+                                                                      ModelFilter.EQ))
+            else:
+                filter_expr = ModelFilter(resource.model.user_id, access_token.user_id, ModelFilter.EQ)
+
         sort_expr = self._parse_sort(params.order_expr, resource.model)
 
         model_facade = self._model_facade_cls(resource.model, self._get_current_connection(request))
@@ -212,6 +227,9 @@ class RoaController(BaseController):
                                                 sort_expr=sort_expr)
         items = [json_serializer.serialize(model, params.fields) for model in models]
 
+        if resource.validator:
+            resource.validator().format_collection(items, request)
+
         models_count = model_facade.count_records(filter_expr=filter_expr)
 
         body = {"items": items,
@@ -251,7 +269,7 @@ class RoaController(BaseController):
 
         return self.handle_resource_options(request, "latest", self._trim_resource_url(resource_url), kwargs)
 
-    def _validate_resource(self, resource, request_body):
+    def _validate_resource(self, resource, request, request_body, existing_resource_id=None):
         '''This method is used to validate the resource. If the resource validation fails an error response is sent. Otherwise
         the newly validated model is returned.'''
 
@@ -260,11 +278,18 @@ class RoaController(BaseController):
 
         model = self._json_serializer_cls(resource).deserialize(request_body.decode())
 
+        action = "create"
+        if existing_resource_id:
+            action = "update"
+
+        self._inject_security_context(request, model)
+        self.validate_security_context(request, action)
+
         if not resource.validator:
             return model
 
         try:
-            resource.validator().validate(model)
+            resource.validator().validate(model, request, existing_resource_id)
         except FantasticoRoaError as ex:
             return self._handle_resource_invalid(resource.version, resource.url, ex)
 
@@ -307,10 +332,16 @@ class RoaController(BaseController):
         if not resource:
             return self._handle_resource_notfound(version, resource_url)
 
+        self._inject_security_context(request, resource.model)
+        access_token = self.validate_security_context(request, "read")
+
         model_facade = self._model_facade_cls(resource.model, self._get_current_connection(request))
 
         try:
             model = model_facade.find_by_pk({model_facade.model_pk_cols[0]: resource_id})
+
+            if not self._is_model_owned_by(model, access_token, resource):
+                model = None
         except FantasticoDbError as dbex:
             return self._handle_resource_dberror(version, resource_url, dbex)
 
@@ -320,6 +351,10 @@ class RoaController(BaseController):
         json_serializer = self._json_serializer_cls(resource)
 
         resource_body = json_serializer.serialize(model, fields)
+
+        if resource.validator and model:
+            resource.validator().format_resource(DictionaryObject(resource_body, immutable=False), request)
+
         resource_body = json.dumps(resource_body)
 
         response = Response(body=resource_body.encode(), content_type="application/json", status_code=200)
@@ -363,12 +398,16 @@ class RoaController(BaseController):
         if not resource:
             return self._handle_resource_notfound(version, resource_url)
 
-        model = self._validate_resource(resource, request.body)
+        model = self._validate_resource(resource, request, request.body)
+        access_token = request.context.security.access_token
 
         if isinstance(model, Response):
             return model
 
         try:
+            if resource.user_dependent and access_token:
+                model.user_id = access_token.user_id
+
             model_facade = self._model_facade_cls(resource.model, self._get_current_connection(request))
             model_id = model_facade.create(model)[0]
         except FantasticoDbError as dbex:
@@ -419,21 +458,22 @@ class RoaController(BaseController):
         if not resource:
             return self._handle_resource_notfound(version, resource_url)
 
-        model = self._validate_resource(resource, request.body)
+        model = self._validate_resource(resource, request, request.body, resource_id)
 
         if isinstance(model, Response):
             return model
 
+        access_token = request.context.security.access_token
+
         model_facade = self._model_facade_cls(resource.model, self._get_current_connection(request))
         pk_col = model_facade.model_pk_cols[0]
 
         try:
             existing_model = model_facade.find_by_pk({pk_col: resource_id})
 
-            if not existing_model:
+            if not existing_model or not self._is_model_owned_by(existing_model, access_token, resource):
                 return self._handle_resource_item_notfound(version, resource_url, resource_id)
 
-
             setattr(model, pk_col.name, resource_id)
             model_facade.update(model)
         except FantasticoDbError as dbex:
@@ -477,12 +517,18 @@ class RoaController(BaseController):
         if not resource:
             return self._handle_resource_notfound(version, resource_url)
 
+        self._inject_security_context(request, resource.model)
+        access_token = self.validate_security_context(request, "delete")
+
         try:
             model_facade = self._model_facade_cls(resource.model, self._get_current_connection(request))
             pk_col = model_facade.model_pk_cols[0]
 
             existing_model = model_facade.find_by_pk({pk_col: resource_id})
 
+            if not self._is_model_owned_by(existing_model, access_token, resource):
+                existing_model = None
+
             if not existing_model:
                 return self._handle_resource_item_notfound(version, resource_url, resource_id)
 
@@ -501,6 +547,47 @@ class RoaController(BaseController):
 
         return self.delete_item(request, "latest", self._trim_resource_url(resource_url), resource_id)
 
+    def validate_security_context(self, request, attr_scope):
+        '''This method triggers security context validation and converts unexpected exceptions to OAuth2UnauthorizedError.
+        If everything is fine this method return the access_token from security context.'''
+
+        security_ctx = request.context.security
+
+        if not attr_scope:
+            return
+
+        try:
+            if not security_ctx.validate_context(attr_scope):
+                raise OAuth2UnauthorizedError("Security context insufficient scopes.")
+        except OAuth2Error:
+            raise
+        except Exception as ex:
+            raise OAuth2UnauthorizedError("Security context validation failed: %s" % str(ex))
+
+        return security_ctx.access_token
+
+    def _inject_security_context(self, request, resource_model):
+        '''This method enrich the current security context with required scopes (if necessary).'''
+
+        if not hasattr(resource_model, "get_required_scopes"):
+            return
+
+        required_scopes_obj = resource_model.get_required_scopes()
+
+        required_scopes_obj.inject_scopes_in_security(request)
+
+    def _is_model_owned_by(self, model, access_token, resource):
+        '''This method is used to detect if a given model can be accessed using the access token. If the resource is not user
+        dependent this method always returns true.'''
+
+        if resource.user_dependent:
+            if model.user_id == access_token.user_id:
+                return True
+
+            return False
+
+        return True
+
 class CollectionParams(object):
     '''This object defines the structure for get_collection supported query parameters.'''
 
