@@ -40,7 +40,9 @@ class BasicSettings(object):
 
         return ["fantastico.middleware.request_middleware.RequestMiddleware",
                 "fantastico.middleware.model_session_middleware.ModelSessionMiddleware",
-                "fantastico.middleware.routing_middleware.RoutingMiddleware"]
+                "fantastico.middleware.routing_middleware.RoutingMiddleware",
+                "fantastico.oauth2.middleware.exceptions_middleware.OAuth2ExceptionsMiddleware",
+                "fantastico.oauth2.middleware.tokens_middleware.OAuth2TokensMiddleware"]
 
     @property
     def supported_languages(self):
@@ -56,6 +58,14 @@ class BasicSettings(object):
                 "fantastico.mvc.controller_registrator.ControllerRouteLoader",
                 "fantastico.roa.resources_registrator.ResourcesRegistrator"]
 
+    @property
+    def mvc_additional_paths(self):
+        '''This property defines additional packages which must be scanned for controllers. You can use this in order to specify
+        custom mvc controllers location which are not found in custom components. For instance, OAuth2 controller resides
+        in core packages of Fantastico.'''
+
+        return ["fantastico.oauth2"]
+
     @property
     def dev_server_port(self):
         '''This property holds development server port. By default this is 12000.'''
@@ -138,6 +148,37 @@ class BasicSettings(object):
 
         return "/api"
 
+    @property
+    def oauth2_idp(self):
+        '''This property holds the configuration for Fantastico default Identity Provider. In most cases you will change the
+        template applied to login screen in order to customize it to your needs. If you want to change
+        the template for login screen make sure your provide relative path to your components root folder
+        (e.g /components/frontend/views/custom_login.html). Moreover, you can also specify the login token validity period (in
+        seconds). It is recommended to set a high value (e.g 2 weeks).
+
+        Additionaly, you can control default idp index page. Usually, Fantastico OAuth2 identity provider login page should be
+        good enough.
+
+        .. code-block:: python
+
+            return {"client_id": "11111111-1111-1111-1111-111111111111",
+                    "template": "/components/frontend/views/custom_login.html",
+                    "expires_in": 1209600,
+                    "idp_index": "/oauth/idp/ui/login"}
+        '''
+
+        return {"client_id": "11111111-1111-1111-1111-111111111111",
+                "template": "login.html",
+                "expires_in": 1209600,
+                "idp_index": "/oauth/idp/ui/login"}
+
+    @property
+    def access_token_validity(self):
+        '''This property defines the validity of an access token in seconds. By default, this property is set
+        to 1h = 3600 seconds.'''
+
+        return 3600
+
 class AwsStageSettings(BasicSettings):
     '''This class provides the configuration profile for Aws Stage environment integration.'''
 
